==> ckeditor_4.5.7+dfsg.orig.tar.xz: ckeditor-dev-4.5.7/plugins/link/lang/ms.js <==
/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'ms', {
	acccessKey: 'Kunci Akses',
	advanced: 'Advanced',
	advisoryContentType: 'Jenis Kandungan Makluman',
	advisoryTitle: 'Tajuk Makluman',
	anchor: {
		toolbar: 'Masukkan/Sunting Pautan',
		menu: 'Ciri-ciri Pautan',
		title: 'Ciri-ciri Pautan',
		name: 'Nama Pautan',
		errorName: 'Sila taip nama pautan',
		remove: 'Remove Anchor'
	},
	anchorId: 'dengan menggunakan ID elemen',
	anchorName: 'dengan menggunakan nama pautan',
	charset: 'Linked Resource Charset',
	cssClasses: 'Kelas-kelas Stylesheet',
	emailAddress: 'Alamat E-Mail',
	emailBody: 'Isi Kandungan Mesej',
	emailSubject: 'Subjek Mesej',
	id: 'Id',
	info: 'Butiran Sambungan',
	langCode: 'Arah Tulisan',
	langDir: 'Arah Tulisan',
	langDirLTR: 'Kiri ke Kanan (LTR)',
	langDirRTL: 'Kanan ke Kiri (RTL)',
	menu: 'Sunting Sambungan',
	name: 'Nama',
	noAnchors: '(Tiada pautan terdapat dalam dokumen ini)',
	noEmail: 'Sila taip alamat e-mail',
	noUrl: 'Sila taip sambungan URL',
	other: '<lain>',
	popupDependent: 'Bergantungan (Netscape)',
	popupFeatures: 'Ciri Tetingkap Popup',
	popupFullScreen: 'Skrin Penuh (IE)',
	popupLeft: 'Posisi Kiri',
	popupLocationBar: 'Bar Lokasi',
	popupMenuBar: 'Bar Menu',
	popupResizable: 'Resizable', // MISSING
	popupScrollBars: 'Bar-bar skrol',
	popupStatusBar: 'Bar Status',
	popupToolbar: 'Toolbar',
	popupTop: 'Posisi Atas',
	rel: 'Relationship', // MISSING
	selectAnchor: 'Sila pilih pautan',
	styles: 'Stail',
	tabIndex: 'Indeks Tab ',
	target: 'Sasaran',
	targetFrame: '<bingkai>',
	targetFrameName: 'Nama Bingkai Sasaran',
	targetPopup: '<tetingkap popup>',
	targetPopupName: 'Nama Tetingkap Popup',
	title: 'Sambungan',
	toAnchor: 'Pautan dalam muka surat ini',
	toEmail: 'E-Mail',
	toUrl: 'URL',
	toolbar: 'Masukkan/Sunting Sambungan',
	type: 'Jenis Sambungan',
	unlink: 'Buang Sambungan',
	upload: 'Muat Naik'
} );

==> ckeditor_4.11.1+dfsg.orig.tar.xz: ckeditor-dev-4.11.1/plugins/link/lang/ms.js <==
﻿/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'ms', {
	acccessKey: 'Kunci Akses',
	advanced: 'Advanced',
	advisoryContentType: 'Jenis Kandungan Makluman',
	advisoryTitle: 'Tajuk Makluman',
	anchor: {
		toolbar: 'Masukkan/Sunting Pautan',
		menu: 'Ciri-ciri Pautan',
		title: 'Ciri-ciri Pautan',
		name: 'Nama Pautan',
		errorName: 'Sila taip nama pautan',
		remove: 'Remove Anchor'
	},
	anchorId: 'dengan menggunakan ID elemen',
	anchorName: 'dengan menggunakan nama pautan',
	charset: 'Linked Resource Charset',
	cssClasses: 'Kelas-kelas Stylesheet',
	download: 'Force Download', // MISSING
	displayText: 'Display Text', // MISSING
	emailAddress: 'Alamat E-Mail',
	emailBody: 'Isi Kandungan Mesej',
	emailSubject: 'Subjek Mesej',
	id: 'Id',
	info: 'Butiran Sambungan',
	langCode: 'Arah Tulisan',
	langDir: 'Arah Tulisan',
	langDirLTR: 'Kiri ke Kanan (LTR)',
	langDirRTL: 'Kanan ke Kiri (RTL)',
	menu: 'Sunting Sambungan',
	name: 'Nama',
	noAnchors: '(Tiada pautan terdapat dalam dokumen ini)',
	noEmail: 'Sila taip alamat e-mail',
	noUrl: 'Sila taip sambungan URL',
	noTel: 'Please type the phone number', // MISSING
	other: '<lain>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Bergantungan (Netscape)',
	popupFeatures: 'Ciri Tetingkap Popup',
	popupFullScreen: 'Skrin Penuh (IE)',
	popupLeft: 'Posisi Kiri',
	popupLocationBar: 'Bar Lokasi',
	popupMenuBar: 'Bar Menu',
	popupResizable: 'Resizable', // MISSING
	popupScrollBars: 'Bar-bar skrol',
	popupStatusBar: 'Bar Status',
	popupToolbar: 'Toolbar',
	popupTop: 'Posisi Atas',
	rel: 'Relationship', // MISSING
	selectAnchor: 'Sila pilih pautan',
	styles: 'Stail',
	tabIndex: 'Indeks Tab ',
	target: 'Sasaran',
	targetFrame: '<bingkai>',
	targetFrameName: 'Nama Bingkai Sasaran',
	targetPopup: '<tetingkap popup>',
	targetPopupName: 'Nama Tetingkap Popup',
	title: 'Sambungan',
	toAnchor: 'Pautan dalam muka surat ini',
	toEmail: 'E-Mail',
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'Masukkan/Sunting Sambungan',
	type: 'Jenis Sambungan',
	unlink: 'Buang Sambungan',
	upload: 'Muat Naik'
} );
